@@ -1,10 +1,10 @@
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.keys import Keys
 
-key_bindings = KeyBindings()
+key_bindings: KeyBindings = KeyBindings()
+
 
 @key_bindings.add(Keys.Tab)
-def _(event):
+def _(event) -> None:
     before_cursor = event.app.current_buffer.document.current_line_before_cursor
-    event.app.current_buffer.insert_text(' '*(4 - len(before_cursor)%4))
-
+    event.app.current_buffer.insert_text(" " * (4 - len(before_cursor) % 4))
